==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/ClusterNetworkEntryFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterNetworkEntryFluent<A extends ClusterNetworkEntryFluent<A>> extends BaseFluent<A>{
  public ClusterNetworkEntryFluent() {
  }
  
  public ClusterNetworkEntryFluent(ClusterNetworkEntry instance) {
    this.copyInstance(instance);
  }
  private String cidr;
  private Integer hostSubnetLength;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterNetworkEntry instance) {
    instance = (instance != null ? instance : new ClusterNetworkEntry());
  
    if (instance != null) {
        this.withCidr(instance.getCidr());
        this.withHostSubnetLength(instance.getHostSubnetLength());
        this.withCidr(instance.getCidr());
        this.withHostSubnetLength(instance.getHostSubnetLength());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getCidr() {
    return this.cidr;
  }
  
  public A withCidr(String cidr) {
    this.cidr=cidr; return (A) this;
  }
  
  public boolean hasCidr() {
    return this.cidr != null;
  }
  
  public Integer getHostSubnetLength() {
    return this.hostSubnetLength;
  }
  
  public A withHostSubnetLength(Integer hostSubnetLength) {
    this.hostSubnetLength=hostSubnetLength; return (A) this;
  }
  
  public boolean hasHostSubnetLength() {
    return this.hostSubnetLength != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterNetworkEntryFluent that = (ClusterNetworkEntryFluent) o;
    if (!java.util.Objects.equals(cidr, that.cidr)) return false;
  
    if (!java.util.Objects.equals(hostSubnetLength, that.hostSubnetLength)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostSubnetLength,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (hostSubnetLength != null) { sb.append("hostSubnetLength:"); sb.append(hostSubnetLength + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/ClusterNetworkEntryFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterNetworkEntryFluent<A extends ClusterNetworkEntryFluent<A>> extends BaseFluent<A>{
  public ClusterNetworkEntryFluent() {
  }
  
  public ClusterNetworkEntryFluent(ClusterNetworkEntry instance) {
    this.copyInstance(instance);
  }
  private String cidr;
  private Integer hostSubnetLength;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterNetworkEntry instance) {
    instance = (instance != null ? instance : new ClusterNetworkEntry());
    if (instance != null) {
          this.withCidr(instance.getCidr());
          this.withHostSubnetLength(instance.getHostSubnetLength());
          this.withCidr(instance.getCidr());
          this.withHostSubnetLength(instance.getHostSubnetLength());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getCidr() {
    return this.cidr;
  }
  
  public A withCidr(String cidr) {
    this.cidr = cidr;
    return (A) this;
  }
  
  public boolean hasCidr() {
    return this.cidr != null;
  }
  
  public Integer getHostSubnetLength() {
    return this.hostSubnetLength;
  }
  
  public A withHostSubnetLength(Integer hostSubnetLength) {
    this.hostSubnetLength = hostSubnetLength;
    return (A) this;
  }
  
  public boolean hasHostSubnetLength() {
    return this.hostSubnetLength != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterNetworkEntryFluent that = (ClusterNetworkEntryFluent) o;
    if (!java.util.Objects.equals(cidr, that.cidr)) return false;
    if (!java.util.Objects.equals(hostSubnetLength, that.hostSubnetLength)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(cidr,  hostSubnetLength,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cidr != null) { sb.append("cidr:"); sb.append(cidr + ","); }
    if (hostSubnetLength != null) { sb.append("hostSubnetLength:"); sb.append(hostSubnetLength + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
